@@ -1,35 +1,22 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testfreebusyganttproxymodel.h"
 #include "freebusyganttproxymodel.h"
-#include "modeltest.h"
 
 #include <CalendarSupport/FreeBusyItem>
 #include <CalendarSupport/FreeBusyItemModel>
 
-#include <KGantt/KGanttGraphicsView>
 #include <KCalendarCore/Attendee>
+#include <KGantt/KGanttGraphicsView>
 
-#include <QTest>
+#include <QAbstractItemModelTester>
 #include <QStandardPaths>
+#include <QTest>
 QTEST_MAIN(FreeBusyGanttProxyModelTest)
 
 using namespace IncidenceEditorNG;
@@ -42,12 +29,12 @@ void FreeBusyGanttProxyModelTest::initTestCase()
 
 void FreeBusyGanttProxyModelTest::testModelValidity()
 {
-    CalendarSupport::FreeBusyItemModel *fbModel = new CalendarSupport::FreeBusyItemModel();
-    FreeBusyGanttProxyModel *ganttModel = new FreeBusyGanttProxyModel();
+    auto fbModel = new CalendarSupport::FreeBusyItemModel();
+    auto ganttModel = new FreeBusyGanttProxyModel();
     ganttModel->setSourceModel(fbModel);
-    ModelTest *modelTest = new ModelTest(ganttModel);
+    auto modelTest = new QAbstractItemModelTester(ganttModel);
 
-    Q_UNUSED(modelTest);
+    Q_UNUSED(modelTest)
 
     QVERIFY(ganttModel->rowCount() == 0);
 
@@ -112,4 +99,7 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
     QCOMPARE(child1_0.data(KGantt::StartTimeRole).toDateTime(), dt3);
     QCOMPARE(child1_1.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeTask);
     QCOMPARE(child1_1.data(KGantt::StartTimeRole).toDateTime(), dt4);
+    delete fbModel;
+    delete ganttModel;
+    delete modelTest;
 }
