@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 
   NOTE: May, 2010. Extracted this code from
         kdepim/incidenceeditors/editorattachments.{h,cpp}
@@ -33,15 +17,14 @@
 
 #include <KIconLoader>
 #include <KUrlMimeData>
-#include <QTemporaryFile>
 #include <QDir>
+#include <QTemporaryFile>
 
 #include <KIconEngine>
 #include <QDrag>
 #include <QKeyEvent>
 #include <QMimeData>
 #include <QMimeDatabase>
-#include <QMimeType>
 
 using namespace IncidenceEditorNG;
 
@@ -52,7 +35,7 @@ AttachmentIconItem::AttachmentIconItem(const KCalendarCore::Attachment &att, QLi
         mAttachment = att;
     } else {
         // for the enterprise, inline attachments are the default
-#ifdef KDEPIM_ENTERPRISE_BUILD
+#if KDEPIM_ENTERPRISE_BUILD
         mAttachment = KCalendarCore::Attachment(QByteArray()); // use the non-uri constructor
         // as we want inline by default
 #else
@@ -128,19 +111,17 @@ bool AttachmentIconItem::isBinary() const
 QPixmap AttachmentIconItem::icon() const
 {
     QMimeDatabase db;
-    return icon(db.mimeTypeForName(mAttachment.mimeType()),
-                mAttachment.uri(), mAttachment.isBinary());
+    return icon(db.mimeTypeForName(mAttachment.mimeType()), mAttachment.uri(), mAttachment.isBinary());
 }
 
 QPixmap AttachmentIconItem::icon(const QMimeType &mimeType, const QString &uri, bool binary)
 {
-    QString iconStr = mimeType.iconName();
+    const QString iconStr = mimeType.iconName();
     QStringList overlays;
     if (!uri.isEmpty() && !binary) {
         overlays << QStringLiteral("emblem-link");
     }
-    return QIcon(new KIconEngine(iconStr, KIconLoader::global(), overlays)).pixmap(
-        KIconLoader::SizeSmallMedium, KIconLoader::SizeSmallMedium);
+    return QIcon(new KIconEngine(iconStr, KIconLoader::global(), overlays)).pixmap(KIconLoader::SizeSmallMedium, KIconLoader::SizeSmallMedium);
 }
 
 void AttachmentIconItem::readAttachment()
@@ -149,8 +130,7 @@ void AttachmentIconItem::readAttachment()
     setFlags(flags() | Qt::ItemIsEditable);
 
     QMimeDatabase db;
-    if (mAttachment.mimeType().isEmpty()
-        || !(db.mimeTypeForName(mAttachment.mimeType()).isDefault())) {
+    if (mAttachment.mimeType().isEmpty() || !(db.mimeTypeForName(mAttachment.mimeType()).isValid())) {
         QMimeType mimeType;
         if (mAttachment.isUri()) {
             mimeType = db.mimeTypeForUrl(QUrl(mAttachment.uri()));
@@ -192,9 +172,7 @@ QUrl AttachmentIconItem::tempFileForAttachment()
     QStringList patterns = db.mimeTypeForName(mAttachment.mimeType()).globPatterns();
 
     if (!patterns.empty()) {
-        file = new QTemporaryFile(QDir::tempPath() + QLatin1String(
-                                      "/attachementview_XXXXX")
-                                  + patterns.first().remove(QLatin1Char('*')));
+        file = new QTemporaryFile(QDir::tempPath() + QLatin1String("/attachementview_XXXXX") + patterns.first().remove(QLatin1Char('*')));
     } else {
         file = new QTemporaryFile();
     }
@@ -210,14 +188,18 @@ QUrl AttachmentIconItem::tempFileForAttachment()
     return mTempFile;
 }
 
-QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) const
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+QMimeData *AttachmentIconView::mimeData(const QList<QListWidgetItem *> items) const // clazy:exclude=function-args-by-ref
+#else
+QMimeData *AttachmentIconView::mimeData(const QList<QListWidgetItem *> &items) const // clazy:exclude=function-args-by-ref
+#endif
 {
     // create a list of the URL:s that we want to drag
     QList<QUrl> urls;
     QStringList labels;
     for (QListWidgetItem *it : items) {
         if (it->isSelected()) {
-            AttachmentIconItem *item = static_cast<AttachmentIconItem *>(it);
+            auto item = static_cast<AttachmentIconItem *>(it);
             if (item->isBinary()) {
                 urls.append(item->tempFileForAttachment());
             } else {
@@ -227,7 +209,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
         }
     }
     if (selectionMode() == NoSelection) {
-        AttachmentIconItem *item = static_cast<AttachmentIconItem *>(currentItem());
+        auto item = static_cast<AttachmentIconItem *>(currentItem());
         if (item) {
             urls.append(QUrl(item->uri()));
             labels.append(QString::fromLatin1(QUrl::toPercentEncoding(item->label())));
@@ -237,7 +219,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
     QMap<QString, QString> metadata;
     metadata[QStringLiteral("labels")] = labels.join(QLatin1Char(':'));
 
-    QMimeData *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
     mimeData->setUrls(urls);
     KUrlMimeData::setMetaData(metadata, mimeData);
     return mimeData;
@@ -250,12 +232,11 @@ QMimeData *AttachmentIconView::mimeData() const
 
 void AttachmentIconView::startDrag(Qt::DropActions supportedActions)
 {
-    Q_UNUSED(supportedActions);
+    Q_UNUSED(supportedActions)
 #ifndef QT_NO_DRAGANDDROP
     QPixmap pixmap;
     if (selectedItems().size() > 1) {
-        pixmap = KIconLoader::global()->loadIcon(QStringLiteral(
-                                                     "mail-attachment"), KIconLoader::Desktop);
+        pixmap = KIconLoader::global()->loadIcon(QStringLiteral("mail-attachment"), KIconLoader::Desktop);
     }
     if (pixmap.isNull()) {
         pixmap = static_cast<AttachmentIconItem *>(currentItem())->icon();
@@ -263,7 +244,7 @@ void AttachmentIconView::startDrag(Qt::DropActions supportedActions)
 
     const QPoint hotspot(pixmap.width() / 2, pixmap.height() / 2);
 
-    QDrag *drag = new QDrag(this);
+    auto drag = new QDrag(this);
     drag->setMimeData(mimeData());
 
     drag->setPixmap(pixmap);
@@ -274,9 +255,8 @@ void AttachmentIconView::startDrag(Qt::DropActions supportedActions)
 
 void AttachmentIconView::keyPressEvent(QKeyEvent *event)
 {
-    if ((event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter)
-        && currentItem() && state() != EditingState) {
-        Q_EMIT itemDoubleClicked(currentItem());   // ugly, but itemActivated() also includes single click
+    if ((event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) && currentItem() && state() != EditingState) {
+        Q_EMIT itemDoubleClicked(currentItem()); // ugly, but itemActivated() also includes single click
         return;
     }
     QListWidget::keyPressEvent(event);
