@@ -11,8 +11,7 @@
         kdepim/incidenceeditors/editorattachments.{h,cpp}
 */
 
-#ifndef INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
-#define INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
+#pragma once
 
 #include <KCalendarCore/Attachment>
 
@@ -34,7 +33,11 @@ public:
     Q_REQUIRED_RESULT QMimeData *mimeData() const;
 
 protected:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
+#else
+    QMimeData *mimeData(const QList<QListWidgetItem *> &items) const override;
+#endif
     void startDrag(Qt::DropActions supportedActions) override;
     void keyPressEvent(QKeyEvent *event) override;
 };
@@ -76,4 +79,3 @@ private:
 };
 }
 
-#endif // INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
