@@ -1,40 +1,28 @@
 /*
-  Copyright (c) 2000,2001,2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
-  Copyright (C) 2010 Casey Link <casey@kdab.com>
+  SPDX-FileCopyrightText: 2000, 2001, 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2010 Casey Link <casey@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_CONFLICTRESOLVER_H
-#define INCIDENCEEDITOR_CONFLICTRESOLVER_H
+#pragma once
 
 #include "incidenceeditor_export.h"
-#include "CalendarSupport/FreeBusyItem"
+#include <CalendarSupport/FreeBusyItem>
 
 #include <QBitArray>
 #include <QSet>
 #include <QTimer>
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class FreeBusyItemModel;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 /**
  * Takes a list of attendees and event info (e.g., min time start, max time end)
  * fetches their freebusy information, then identifies conflicts and periods of non-conflict.
@@ -103,7 +91,7 @@ public:
      * @see setMandatoryRoles
      * @see setAllowedWeekdays
      */
-    KCalendarCore::Period::List availableSlots() const;
+    Q_REQUIRED_RESULT KCalendarCore::Period::List availableSlots() const;
 
     /**
       Finds a free slot in the future which has at least the same size as
@@ -111,8 +99,6 @@ public:
     */
     Q_REQUIRED_RESULT bool findFreeSlot(const KCalendarCore::Period &dateTimeRange);
 
-    Q_REQUIRED_RESULT QList<CalendarSupport::FreeBusyItem::Ptr> freeBusyItems() const;
-
     CalendarSupport::FreeBusyItemModel *model() const;
 
 Q_SIGNALS:
@@ -139,10 +125,10 @@ public Q_SLOTS:
      *
      * These control the timeframe for which conflicts are to be resolved.
      */
-    void setEarliestDate(const QDate &newDate);
-    void setEarliestTime(const QTime &newTime);
-    void setLatestDate(const QDate &newDate);
-    void setLatestTime(const QTime &newTime);
+    void setEarliestDate(QDate newDate);
+    void setEarliestTime(QTime newTime);
+    void setLatestDate(QDate newDate);
+    void setLatestTime(QTime newTime);
 
     void setEarliestDateTime(const QDateTime &newDateTime);
     void setLatestDateTime(const QDateTime &newDateTime);
@@ -182,7 +168,7 @@ private:
     void calculateConflicts();
 
     KCalendarCore::Period mTimeframeConstraint; //!< the datetime range for outside of which
-    //free slots won't be searched.
+    // free slots won't be searched.
     KCalendarCore::Period::List mAvailableSlots;
 
     QTimer mCalculateTimer; //!< A timer is used control the calculation of conflicts
@@ -200,4 +186,3 @@ private:
 };
 }
 
-#endif
