@@ -9,6 +9,8 @@
 
 #include "incidenceeditor-ng.h"
 
+#include <memory>
+
 namespace Ui
 {
 class EventOrTodoDesktop;
@@ -16,6 +18,8 @@ class EventOrTodoDesktop;
 
 namespace IncidenceEditorNG
 {
+class IncidenceCompletionPriorityPrivate;
+
 class IncidenceCompletionPriority : public IncidenceEditor
 {
     Q_OBJECT
@@ -31,8 +35,8 @@ public:
     bool isDirty() const override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class IncidenceCompletionPriorityPrivate;
+    std::unique_ptr<IncidenceCompletionPriorityPrivate> const d;
 };
 }
 
