@@ -1,31 +1,20 @@
 /*
-  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCEDEFAULTS_H
-#define INCIDENCEEDITOR_INCIDENCEDEFAULTS_H
+#pragma once
 
 #include "incidenceeditor_export.h"
 
 #include <KCalendarCore/Incidence>
 
-namespace IncidenceEditorNG {
+#include <memory>
+
+namespace IncidenceEditorNG
+{
 class IncidenceDefaultsPrivate;
 /**
  * @brief The IncidenceDefaults class
@@ -42,7 +31,10 @@ public:
     /**
       Sets the attachments that are added by default to incidences.
     */
-    void setAttachments(const QStringList &attachments, const QStringList &attachmentMimetypes = QStringList(), const QStringList &attachmentLabels = QStringList(), bool inlineAttachment = false);
+    void setAttachments(const QStringList &attachments,
+                        const QStringList &attachmentMimetypes = QStringList(),
+                        const QStringList &attachmentLabels = QStringList(),
+                        bool inlineAttachment = false);
 
     /**
       Sets the attendees that are added by default to incidences.
@@ -111,9 +103,8 @@ public:
     Q_REQUIRED_RESULT static QString invalidEmailAddress();
 
 private:
-    IncidenceDefaultsPrivate *const d_ptr;
+    std::unique_ptr<IncidenceDefaultsPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(IncidenceDefaults)
 };
 }
 
-#endif
