@@ -10,7 +10,7 @@
 #include "incidencedialog.h"
 
 #include <Akonadi/Calendar/IncidenceChanger>
-#include <Item>
+#include <Akonadi/Item>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Todo>
 
@@ -74,6 +74,7 @@ IncidenceDialog *IncidenceDialogFactory::createTodoEditor(const QString &summary
                                      flags);
     dialog->selectCollection(defaultCollection);
     dialog->load(item);
+    dialog->setInitiallyDirty(true);
     return dialog;
 }
 
@@ -113,6 +114,7 @@ IncidenceDialog *IncidenceDialogFactory::createEventEditor(const QString &summar
 
     dialog->selectCollection(defaultCollection);
     dialog->load(item);
+    dialog->setInitiallyDirty(true);
 
     return dialog;
 }
