@@ -1,37 +1,20 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "incidenceresource.h"
-#include "resourcemanagement.h"
-#include "resourcemodel.h"
 #include "attendeecomboboxdelegate.h"
 #include "attendeelineeditdelegate.h"
 #include "incidencedatetime.h"
+#include "resourcemanagement.h"
+#include "resourcemodel.h"
 
 #include "ui_dialogdesktop.h"
 
 #include <KDescendantsProxyModel>
 #include <KEmailAddress>
-
 #include <QCompleter>
 
 using namespace IncidenceEditorNG;
@@ -64,23 +47,20 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     , resourceDialog(new ResourceManagement())
 {
     setObjectName(QStringLiteral("IncidenceResource"));
-    connect(resourceDialog, &ResourceManagement::accepted, this,
-            &IncidenceResource::dialogOkPressed);
+    connect(resourceDialog, &ResourceManagement::accepted, this, &IncidenceResource::dialogOkPressed);
 
-    connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
-            &IncidenceResource::slotDateChanged);
-    connect(mDateTime, &IncidenceDateTime::endDateChanged, this,
-            &IncidenceResource::slotDateChanged);
+    connect(mDateTime, &IncidenceDateTime::startDateChanged, this, &IncidenceResource::slotDateChanged);
+    connect(mDateTime, &IncidenceDateTime::endDateChanged, this, &IncidenceResource::slotDateChanged);
 
     QStringList attrs;
-    attrs << QStringLiteral("cn") <<  QStringLiteral("mail");
+    attrs << QStringLiteral("cn") << QStringLiteral("mail");
 
     completer = new QCompleter(this);
-    ResourceModel *model = new ResourceModel(attrs, this);
+    auto model = new ResourceModel(attrs, this);
 
-    KDescendantsProxyModel *proxyModel = new KDescendantsProxyModel(this);
+    auto proxyModel = new KDescendantsProxyModel(this);
     proxyModel->setSourceModel(model);
-    SwitchRoleProxy *proxyModel2 = new SwitchRoleProxy(this);
+    auto proxyModel2 = new SwitchRoleProxy(this);
     proxyModel2->setSourceModel(proxyModel);
 
     completer->setModel(proxyModel2);
@@ -88,36 +68,26 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     completer->setWrapAround(false);
     mUi->mNewResource->setCompleter(completer);
 
-    AttendeeLineEditDelegate *attendeeDelegate = new AttendeeLineEditDelegate(this);
+    auto attendeeDelegate = new AttendeeLineEditDelegate(this);
 
-    ResourceFilterProxyModel *filterProxyModel = new ResourceFilterProxyModel(this);
+    auto filterProxyModel = new ResourceFilterProxyModel(this);
     filterProxyModel->setDynamicSortFilter(true);
     filterProxyModel->setSourceModel(dataModel);
 
     mUi->mResourcesTable->setModel(filterProxyModel);
-    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Role,
-                                                   ieAttendee->roleDelegate());
+    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Role, ieAttendee->roleDelegate());
     mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::FullName, attendeeDelegate);
-    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Status,
-                                                   ieAttendee->stateDelegate());
-    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Response,
-                                                   ieAttendee->responseDelegate());
+    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Status, ieAttendee->stateDelegate());
+    mUi->mResourcesTable->setItemDelegateForColumn(AttendeeTableModel::Response, ieAttendee->responseDelegate());
 
-    connect(mUi->mFindResourcesButton, &QPushButton::clicked, this,
-            &IncidenceResource::findResources);
-    connect(mUi->mBookResourceButton, &QPushButton::clicked, this,
-            &IncidenceResource::bookResource);
-    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this,
-            &IncidenceResource::layoutChanged);
-    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this,
-            &IncidenceResource::updateCount);
-    connect(filterProxyModel, &ResourceFilterProxyModel::rowsInserted, this,
-            &IncidenceResource::updateCount);
-    connect(filterProxyModel, &ResourceFilterProxyModel::rowsRemoved, this,
-            &IncidenceResource::updateCount);
+    connect(mUi->mFindResourcesButton, &QPushButton::clicked, this, &IncidenceResource::findResources);
+    connect(mUi->mBookResourceButton, &QPushButton::clicked, this, &IncidenceResource::bookResource);
+    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this, &IncidenceResource::layoutChanged);
+    connect(filterProxyModel, &ResourceFilterProxyModel::layoutChanged, this, &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::rowsInserted, this, &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::rowsRemoved, this, &IncidenceResource::updateCount);
     // only update when FullName is changed
-    connect(filterProxyModel, &ResourceFilterProxyModel::dataChanged, this,
-            &IncidenceResource::updateCount);
+    connect(filterProxyModel, &ResourceFilterProxyModel::dataChanged, this, &IncidenceResource::updateCount);
 }
 
 IncidenceResource::~IncidenceResource()
@@ -127,7 +97,7 @@ IncidenceResource::~IncidenceResource()
 
 void IncidenceResource::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Q_UNUSED(incidence);
+    Q_UNUSED(incidence)
     slotDateChanged();
 }
 
@@ -138,13 +108,13 @@ void IncidenceResource::slotDateChanged()
 
 void IncidenceResource::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Q_UNUSED(incidence);
-    //all logic inside IncidenceAtendee (using same model)
+    Q_UNUSED(incidence)
+    // all logic inside IncidenceAtendee (using same model)
 }
 
 bool IncidenceResource::isDirty() const
 {
-    //all logic inside IncidenceAtendee (using same model)
+    // all logic inside IncidenceAtendee (using same model)
     return false;
 }
 
@@ -153,7 +123,8 @@ void IncidenceResource::bookResource()
     if (mUi->mNewResource->text().trimmed().isEmpty()) {
         return;
     }
-    QString name, email;
+    QString name;
+    QString email;
     KEmailAddress::extractEmailAddressAndName(mUi->mNewResource->text(), email, name);
     KCalendarCore::Attendee attendee(name, email);
     attendee.setCuType(KCalendarCore::Attendee::Resource);
