@@ -1,21 +1,7 @@
 /*
- * Copyright 2014  Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  *
  */
 #include "resourceitem.h"
@@ -43,7 +29,7 @@ ResourceItem::ResourceItem(const KLDAP::LdapDN &dn, const QStringList &attrs, co
         mLdapClient.setAttributes(attrs);
     } else {
         itemData.reserve(mAttrs.count());
-        for (const QString &header : qAsConst(mAttrs)) {
+        for (const QString &header : std::as_const(mAttrs)) {
             itemData << header;
         }
     }
@@ -67,7 +53,7 @@ int ResourceItem::childNumber() const
 {
     if (parentItem) {
         int i = 0;
-        for (const ResourceItem::Ptr &child : qAsConst(parentItem->childItems)) {
+        for (const ResourceItem::Ptr &child : std::as_const(parentItem->childItems)) {
             if (child == this) {
                 return i;
             }
@@ -152,9 +138,9 @@ const KLDAP::LdapClient &ResourceItem::ldapClient() const
 
 void ResourceItem::slotLDAPResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &obj)
 {
-    Q_UNUSED(client);
+    Q_UNUSED(client)
     mLdapObject = obj;
-    for (const QString &header : qAsConst(mAttrs)) {
+    for (const QString &header : std::as_const(mAttrs)) {
         if (!obj.attributes()[header].isEmpty()) {
             itemData << QString::fromUtf8(obj.attributes()[header][0]);
         } else {
