@@ -4,16 +4,15 @@
  * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
-#ifndef RESOURCEMANAGEMENT_H
-#define RESOURCEMANAGEMENT_H
+#pragma once
 
 #include "incidenceeditor_export.h"
 
 #include <KLDAP/LdapClient>
 #include <KLDAP/LdapClientSearch>
 
-#include <CalendarSupport/FreeBusyCalendar>
 #include "resourceitem.h"
+#include <CalendarSupport/FreeBusyCalendar>
 
 #include <EventViews/ViewCalendar>
 
@@ -23,11 +22,13 @@ class Ui_resourceManagement;
 
 class QItemSelectionModel;
 
-namespace EventViews {
+namespace EventViews
+{
 class AgendaView;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 /**
  * @brief The ResourceManagement class
  */
@@ -36,7 +37,7 @@ class INCIDENCEEDITOR_EXPORT ResourceManagement : public QDialog
     Q_OBJECT
 public:
     explicit ResourceManagement(QWidget *parent = nullptr);
-    ~ResourceManagement();
+    ~ResourceManagement() override;
 
     Q_REQUIRED_RESULT ResourceItem::Ptr selectedItem() const;
 
@@ -82,4 +83,3 @@ private:
     EventViews::AgendaView *mAgendaView = nullptr;
 };
 }
-#endif // RESOURCEMANAGEMENT_H
